OptionalCow

Struct OptionalCow 

#[repr(transparent)]
pub struct OptionalCow<'a, T, Marker>(pub Option<Cow<'a, T>>, _) where T: ToOwned + ?Sized, Marker: Clone + Copy + 'static;
Universal wrapper with transparent option of copy on write reference emphasizing a specific aspect of identity of its internal type.

Tuple Fields

0: Option<Cow<'a, T>>

Implementations

Source

impl<'a, T, Marker> OptionalCow<'a, T, Marker>
where T: ToOwned + ?Sized, Marker: Clone + Copy + 'static,

pub fn into_owned(&self) -> <T as ToOwned>::Owned
where <T as ToOwned>::Owned: Default,

Creates owned data from borrowed data, usually by cloning.

pub fn is_borrowed(&self) -> bool

Check is it borrowed.

pub fn is_some(&self) -> bool

Check does it have some value.

pub fn none() -> OptionalCow<'a, T, Marker>

Constructor returning none.

pub fn new(src: <T as ToOwned>::Owned) -> OptionalCow<'a, T, Marker>

Just a constructor.

pub fn new_with_ref(src: &'a T) -> OptionalCow<'a, T, Marker>

Just a constructor.

pub fn new_with_inner(src: Option<Cow<'a, T>>) -> OptionalCow<'a, T, Marker>

Just a constructor.

pub fn inner(self) -> Option<Cow<'a, T>>

Just a constructor.

Methods from Deref<Target = Option<Cow<'a, T>>>

1.0.0 · Source

pub fn is_some(&self) -> bool

Returns true if the option is a Some value.

Examples
let x: Option<u32> = Some(2);
assert_eq!(x.is_some(), true);

let x: Option<u32> = None;
assert_eq!(x.is_some(), false);
1.0.0 · Source

pub fn is_none(&self) -> bool

Returns true if the option is a None value.

Examples
let x: Option<u32> = Some(2);
assert_eq!(x.is_none(), false);

let x: Option<u32> = None;
assert_eq!(x.is_none(), true);
1.0.0 · Source

pub fn as_ref(&self) -> Option<&T>

Converts from &Option<T> to Option<&T>.

Examples

Calculates the length of an Option<String> as an Option<usize> without moving the String. The map method takes the self argument by value, consuming the original, so this technique uses as_ref to first take an Option to a reference to the value inside the original.

let text: Option<String> = Some("Hello, world!".to_string());
// First, cast `Option<String>` to `Option<&String>` with `as_ref`,
// then consume *that* with `map`, leaving `text` on the stack.
let text_length: Option<usize> = text.as_ref().map(|s| s.len());
println!("still can print text: {text:?}");
1.33.0 · Source

pub fn as_pin_ref(self: Pin<&Option<T>>) -> Option<Pin<&T>>

Converts from Pin<&Option<T>> to Option<Pin<&T>>.

1.33.0 · Source

pub fn as_pin_mut(self: Pin<&mut Option<T>>) -> Option<Pin<&mut T>>

Converts from Pin<&mut Option<T>> to Option<Pin<&mut T>>.

1.75.0 · Source

pub fn as_slice(&self) -> &[T]

Returns a slice of the contained value, if any. If this is None, an empty slice is returned. This can be useful to have a single type of iterator over an Option or slice.

Note: Should you have an Option<&T> and wish to get a slice of T, you can unpack it via opt.map_or(&[], std::slice::from_ref).

Examples
assert_eq!(
    [Some(1234).as_slice(), None.as_slice()],
    [&[1234][..], &[][..]],
);

The inverse of this function is (discounting borrowing) [_]::first:

for i in [Some(1234_u16), None] {
    assert_eq!(i.as_ref(), i.as_slice().first());
}
1.40.0 · Source

pub fn as_deref(&self) -> Option<&<T as Deref>::Target>
where T: Deref,

Converts from Option<T> (or &Option<T>) to Option<&T::Target>.

Leaves the original Option in-place, creating a new one with a reference to the original one, additionally coercing the contents via Deref.

Examples
let x: Option<String> = Some("hey".to_owned());
assert_eq!(x.as_deref(), Some("hey"));

let x: Option<String> = None;
assert_eq!(x.as_deref(), None);
1.0.0 · Source

pub fn iter(&self) -> Iter<'_, T>

Returns an iterator over the possibly contained value.

Examples
let x = Some(4);
assert_eq!(x.iter().next(), Some(&4));

let x: Option<u32> = None;
assert_eq!(x.iter().next(), None);