#[repr(transparent)]pub struct OptionalCow<'a, T, Marker>(pub Option<Cow<'a, T>>, _)
where
T: ToOwned + ?Sized,
Marker: Clone + Copy + 'static;Expand description
Universal wrapper with transparent option of copy on write reference emphasizing a specific aspect of identity of its internal type.
Tuple Fields
0: Option<Cow<'a, T>>Implementations
Sourceimpl<'a, T, Marker> OptionalCow<'a, T, Marker>
impl<'a, T, Marker> OptionalCow<'a, T, Marker>
Sourcepub fn into_owned(&self) -> <T as ToOwned>::Owned
pub fn into_owned(&self) -> <T as ToOwned>::Owned
Creates owned data from borrowed data, usually by cloning.
Sourcepub fn is_borrowed(&self) -> bool
pub fn is_borrowed(&self) -> bool
Check is it borrowed.
Sourcepub fn none() -> OptionalCow<'a, T, Marker>
pub fn none() -> OptionalCow<'a, T, Marker>
Constructor returning none.
Sourcepub fn new(src: <T as ToOwned>::Owned) -> OptionalCow<'a, T, Marker>
pub fn new(src: <T as ToOwned>::Owned) -> OptionalCow<'a, T, Marker>
Just a constructor.
Sourcepub fn new_with_ref(src: &'a T) -> OptionalCow<'a, T, Marker>
pub fn new_with_ref(src: &'a T) -> OptionalCow<'a, T, Marker>
Just a constructor.
Sourcepub fn new_with_inner(src: Option<Cow<'a, T>>) -> OptionalCow<'a, T, Marker>
pub fn new_with_inner(src: Option<Cow<'a, T>>) -> OptionalCow<'a, T, Marker>
Just a constructor.
Methods from Deref<Target = Option<Cow<'a, T>>>
1.0.0 · Sourcepub fn as_ref(&self) -> Option<&T>
pub fn as_ref(&self) -> Option<&T>
Converts from &Option<T> to Option<&T>.
Examples
Calculates the length of an Option<String> as an Option<usize>
without moving the String. The map method takes the self argument by value,
consuming the original, so this technique uses as_ref to first take an Option to a
reference to the value inside the original.
let text: Option<String> = Some("Hello, world!".to_string());
// First, cast `Option<String>` to `Option<&String>` with `as_ref`,
// then consume *that* with `map`, leaving `text` on the stack.
let text_length: Option<usize> = text.as_ref().map(|s| s.len());
println!("still can print text: {text:?}");1.75.0 · Sourcepub fn as_slice(&self) -> &[T]
pub fn as_slice(&self) -> &[T]
Returns a slice of the contained value, if any. If this is None, an
empty slice is returned. This can be useful to have a single type of
iterator over an Option or slice.
Note: Should you have an Option<&T> and wish to get a slice of T,
you can unpack it via opt.map_or(&[], std::slice::from_ref).
Examples
assert_eq!(
[Some(1234).as_slice(), None.as_slice()],
[&[1234][..], &[][..]],
);The inverse of this function is (discounting
borrowing) [_]::first:
for i in [Some(1234_u16), None] {
assert_eq!(i.as_ref(), i.as_slice().first());
}1.40.0 · Sourcepub fn as_deref(&self) -> Option<&<T as Deref>::Target>where
T: Deref,
pub fn as_deref(&self) -> Option<&<T as Deref>::Target>where
T: Deref,
Converts from Option<T> (or &Option<T>) to Option<&T::Target>.
Leaves the original Option in-place, creating a new one with a reference
to the original one, additionally coercing the contents via Deref.
Examples
let x: Option<String> = Some("hey".to_owned());
assert_eq!(x.as_deref(), Some("hey"));
let x: Option<String> = None;
assert_eq!(x.as_deref(), None);Trait Implementations
Sourceimpl<'a, T, Marker> Clone for OptionalCow<'a, T, Marker>
impl<'a, T, Marker> Clone for OptionalCow<'a, T, Marker>
Sourcefn clone(&self) -> OptionalCow<'a, T, Marker>
fn clone(&self) -> OptionalCow<'a, T, Marker>
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl<'a, T, Marker> Debug for OptionalCow<'a, T, Marker>
impl<'a, T, Marker> Debug for OptionalCow<'a, T, Marker>
Sourceimpl<'a, T, Marker> Default for OptionalCow<'a, T, Marker>
impl<'a, T, Marker> Default for OptionalCow<'a, T, Marker>
Sourcefn default() -> OptionalCow<'a, T, Marker>
fn default() -> OptionalCow<'a, T, Marker>
Sourceimpl<'a, T, Marker> Deref for OptionalCow<'a, T, Marker>
impl<'a, T, Marker> Deref for OptionalCow<'a, T, Marker>
Sourceimpl<K, V, Borrowed, Marker> Fields<K, OptionalCow<'_, Borrowed, Marker>> for BTreeMap<K, V>
impl<K, V, Borrowed, Marker> Fields<K, OptionalCow<'_, Borrowed, Marker>> for BTreeMap<K, V>
Sourcetype Key<'k> = &'k K
where
BTreeMap<K, V>: 'k,
K: 'k
type Key<'k> = &'k K where BTreeMap<K, V>: 'k, K: 'k
'k.
This ensures the values’ lifetimes are tied to the entity being iterated over.Sourcetype Val<'v> = OptionalCow<'v, Borrowed, Marker>
where
BTreeMap<K, V>: 'v,
V: 'v
type Val<'v> = OptionalCow<'v, Borrowed, Marker> where BTreeMap<K, V>: 'v, V: 'v
'v.
This ensures the values’ lifetimes are tied to the entity being iterated over.Sourcefn fields<'s>(&'s self) -> impl IteratorTrait
fn fields<'s>(&'s self) -> impl IteratorTrait
Sourceimpl<K, V, Borrowed, Marker> Fields<K, OptionalCow<'_, Borrowed, Marker>> for HashMap<K, V>
impl<K, V, Borrowed, Marker> Fields<K, OptionalCow<'_, Borrowed, Marker>> for HashMap<K, V>
Sourcetype Key<'k> = &'k K
where
HashMap<K, V>: 'k,
K: 'k
type Key<'k> = &'k K where HashMap<K, V>: 'k, K: 'k
'k.
This ensures the values’ lifetimes are tied to the entity being iterated over.Sourcetype Val<'v> = OptionalCow<'v, Borrowed, Marker>
where
HashMap<K, V>: 'v,
V: 'v
type Val<'v> = OptionalCow<'v, Borrowed, Marker> where HashMap<K, V>: 'v, V: 'v
'v.
This ensures the values’ lifetimes are tied to the entity being iterated over.Sourcefn fields<'s>(&'s self) -> impl IteratorTrait
fn fields<'s>(&'s self) -> impl IteratorTrait
Sourceimpl<V, Borrowed, Marker> Fields<usize, OptionalCow<'_, Borrowed, Marker>> for BTreeSet<V>
impl<V, Borrowed, Marker> Fields<usize, OptionalCow<'_, Borrowed, Marker>> for BTreeSet<V>
Sourcetype Key<'k> = usize
where
BTreeSet<V>: 'k,
usize: 'k
type Key<'k> = usize where BTreeSet<V>: 'k, usize: 'k
'k.
This ensures the values’ lifetimes are tied to the entity being iterated over.Sourcetype Val<'v> = OptionalCow<'v, Borrowed, Marker>
where
BTreeSet<V>: 'v
type Val<'v> = OptionalCow<'v, Borrowed, Marker> where BTreeSet<V>: 'v
'v.
This ensures the values’ lifetimes are tied to the entity being iterated over.Sourcefn fields<'s>(&'s self) -> impl IteratorTrait
fn fields<'s>(&'s self) -> impl IteratorTrait
Sourceimpl<V, Borrowed, Marker> Fields<usize, OptionalCow<'_, Borrowed, Marker>> for HashSet<V>
impl<V, Borrowed, Marker> Fields<usize, OptionalCow<'_, Borrowed, Marker>> for HashSet<V>
Sourcetype Key<'k> = usize
where
HashSet<V>: 'k,
usize: 'k
type Key<'k> = usize where HashSet<V>: 'k, usize: 'k
'k.
This ensures the values’ lifetimes are tied to the entity being iterated over.Sourcetype Val<'v> = OptionalCow<'v, Borrowed, Marker>
where
HashSet<V>: 'v
type Val<'v> = OptionalCow<'v, Borrowed, Marker> where HashSet<V>: 'v
'v.
This ensures the values’ lifetimes are tied to the entity being iterated over.Sourcefn fields<'s>(&'s self) -> impl IteratorTrait
fn fields<'s>(&'s self) -> impl IteratorTrait
Sourceimpl<V, Borrowed, Marker> Fields<usize, OptionalCow<'_, Borrowed, Marker>> for LinkedList<V>
impl<V, Borrowed, Marker> Fields<usize, OptionalCow<'_, Borrowed, Marker>> for LinkedList<V>
Sourcetype Key<'k> = usize
where
LinkedList<V>: 'k,
usize: 'k
type Key<'k> = usize where LinkedList<V>: 'k, usize: 'k
'k.
This ensures the values’ lifetimes are tied to the entity being iterated over.Sourcetype Val<'v> = OptionalCow<'v, Borrowed, Marker>
where
LinkedList<V>: 'v
type Val<'v> = OptionalCow<'v, Borrowed, Marker> where LinkedList<V>: 'v
'v.
This ensures the values’ lifetimes are tied to the entity being iterated over.Sourcefn fields<'s>(&'s self) -> impl IteratorTrait
fn fields<'s>(&'s self) -> impl IteratorTrait
Sourceimpl<V, Borrowed, Marker> Fields<usize, OptionalCow<'_, Borrowed, Marker>> for Vec<V>
impl<V, Borrowed, Marker> Fields<usize, OptionalCow<'_, Borrowed, Marker>> for Vec<V>
Sourcetype Key<'k> = usize
where
Vec<V>: 'k,
usize: 'k
type Key<'k> = usize where Vec<V>: 'k, usize: 'k
'k.
This ensures the values’ lifetimes are tied to the entity being iterated over.Sourcetype Val<'v> = OptionalCow<'v, Borrowed, Marker>
where
Vec<V>: 'v
type Val<'v> = OptionalCow<'v, Borrowed, Marker> where Vec<V>: 'v
'v.
This ensures the values’ lifetimes are tied to the entity being iterated over.Sourcefn fields<'s>(&'s self) -> impl IteratorTrait
fn fields<'s>(&'s self) -> impl IteratorTrait
Sourceimpl<V, Borrowed, Marker> Fields<usize, OptionalCow<'_, Borrowed, Marker>> for VecDeque<V>
impl<V, Borrowed, Marker> Fields<usize, OptionalCow<'_, Borrowed, Marker>> for VecDeque<V>
Sourcetype Key<'k> = usize
where
VecDeque<V>: 'k,
usize: 'k
type Key<'k> = usize where VecDeque<V>: 'k, usize: 'k
'k.
This ensures the values’ lifetimes are tied to the entity being iterated over.Sourcetype Val<'v> = OptionalCow<'v, Borrowed, Marker>
where
VecDeque<V>: 'v
type Val<'v> = OptionalCow<'v, Borrowed, Marker> where VecDeque<V>: 'v
'v.
This ensures the values’ lifetimes are tied to the entity being iterated over.Sourcefn fields<'s>(&'s self) -> impl IteratorTrait
fn fields<'s>(&'s self) -> impl IteratorTrait
Sourceimpl<'a, T, Marker> From<&'a T> for OptionalCow<'a, T, Marker>
impl<'a, T, Marker> From<&'a T> for OptionalCow<'a, T, Marker>
Sourcefn from(src: &'a T) -> OptionalCow<'a, T, Marker>
fn from(src: &'a T) -> OptionalCow<'a, T, Marker>
Sourceimpl<'a, T, Marker> From<Cow<'a, T>> for OptionalCow<'a, T, Marker>
impl<'a, T, Marker> From<Cow<'a, T>> for OptionalCow<'a, T, Marker>
Sourcefn from(src: Cow<'a, T>) -> OptionalCow<'a, T, Marker>
fn from(src: Cow<'a, T>) -> OptionalCow<'a, T, Marker>
Sourceimpl<'a, T, Marker> PartialEq for OptionalCow<'a, T, Marker>
impl<'a, T, Marker> PartialEq for OptionalCow<'a, T, Marker>
impl<'a, T, Marker> Eq for OptionalCow<'a, T, Marker>