pub trait TableRows {
type RowKey;
type Row: Cells<Self::CellKey>;
type CellKey: CellKey + ?Sized;
// Required method
fn rows(&self) -> impl IteratorTrait<Item = &Self::Row>;
}Expand description
Trait for iterating over rows in a table.
TableRows provides an interface to access all rows in a table,
allowing iteration over the data structure.
Associated Types
-
RowKey: The type used to identify each row. -
Row: The type representing a row, which must implementCellsfor the specifiedCellKeyandCellRepr. -
CellKey: The type used to identify cells within a row, requiring implementation of theKeytrait. -
CellRepr: The type representing the content of a cell, requiring implementation of theCellReprtrait.
Required Methods
rows(&self) -> impl IteratorTrait<Item = &Self::Row>: Returns an iterator over all rows in the table.
Required Associated Types
Required Methods
Sourcefn rows(&self) -> impl IteratorTrait<Item = &Self::Row>
fn rows(&self) -> impl IteratorTrait<Item = &Self::Row>
Returns an iterator over all rows of the table.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.